LabelMaker

Trait LabelMaker 

pub trait LabelMaker {
    // Required methods
    fn new() -> Self;
    fn from_const(val: u64) -> Self;
    fn from_label(other: &Self) -> Self;
    fn from_label_offset(other: &Self, offset: i64) -> Self;
}
Methods for creating a Label (or a RealLabel, but don’t do that).

Required Methods

fn new() -> Self

Create an undefined label.

fn from_const(val: u64) -> Self

Create a label with a constant value val.

fn from_label(other: &Self) -> Self

Create a label whose value is equal to other.

fn from_label_offset(other: &Self, offset: i64) -> Self

Create a label whose value is equal to other plus offset.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors