pub trait LabelMaker {
// Required methods
fn new() -> Self;
fn from_const(val: u64) -> Self;
fn from_label(other: &Self) -> Self;
fn from_label_offset(other: &Self, offset: i64) -> Self;
}Expand description
Methods for creating a Label (or a RealLabel, but don’t do that).
Required Methods
Sourcefn from_const(val: u64) -> Self
fn from_const(val: u64) -> Self
Create a label with a constant value val.
Sourcefn from_label(other: &Self) -> Self
fn from_label(other: &Self) -> Self
Create a label whose value is equal to other.
Sourcefn from_label_offset(other: &Self, offset: i64) -> Self
fn from_label_offset(other: &Self, offset: i64) -> Self
Create a label whose value is equal to other plus offset.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".